@@ -7,7 +7,7 @@
 #
 
 package CPANPLUS::Dist::Fedora;
-$CPANPLUS::Dist::Fedora::VERSION = '0.4.0';
+$CPANPLUS::Dist::Fedora::VERSION = '0.4.1';
 use strict;
 use warnings;
 
@@ -37,6 +37,7 @@ sub _get_spec_template
     # Dealing with DATA gets increasingly messy, IMHO
     # So we're going to use the Template Toolkit instead
     return <<'END_SPEC';
+[% SET makefile_pl_common = "INSTALLDIRS=vendor NO_PERLLOCAL=1 NO_PACKLIST=1" %]
 [% BLOCK rpm_req_wrap %][%- rpm_prefix %] [% rpm_req(br) -%][%- IF (brs.$br != 0) %] >= [% brs.$br %][% END -%][%- "\n" -%][% END %]
 Name:       [% status.rpmname %]
 Version:    [% status.distvers %]
@@ -71,15 +72,17 @@ BuildRequires: perl-interpreter
 
 %build
 [% IF (!status.is_noarch) -%]
-[% perl_exe %] Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}" INSTALLVENDORLIB=%{perl_vendorlib} INSTALLVENDORMAN3DIR=%{_mandir}/man3
+[% perl_exe %] Makefile.PL [% makefile_pl_common %] OPTIMIZE="%{optflags}"
 [% ELSE -%]
-[% perl_exe %] Makefile.PL INSTALLDIRS=vendor INSTALLVENDORLIB=%{perl_vendorlib} INSTALLVENDORMAN3DIR=%{_mandir}/man3
+[% perl_exe %] Makefile.PL [% makefile_pl_common %]
 [% END -%]
 %{make_build}
 
 %install
 %{make_install}
+[% IF 0 -%]
 find %{buildroot} -type f \( -name .packlist -o -name perllocal.pod \) -exec rm -f {} ';'
+[%- END -%]
 [% IF (!status.is_noarch) -%]
 find %{buildroot} -type f -name '*.bs' -a -size 0 -exec rm -f {} ';'
 [% END -%]
@@ -91,7 +94,9 @@ find %{buildroot} -depth -type d -exec rmdir {} 2>/dev/null ';'
 make test
 
 %files
+[%- IF 0 -%]
 %defattr(-,root,root,-)[% "\n" %]
+[%- END -%]
 [%- IF licensefiles %]%license [% licensefiles _ "\n" %][%- END -%]
 %doc [% docfiles %]
 [% IF (status.is_noarch) -%]
@@ -703,7 +708,7 @@ CPANPLUS::Dist::Fedora - a cpanplus backend to build Fedora/RedHat rpms
 
 =head1 VERSION
 
-version 0.4.0
+version 0.4.1
 
 =head1 SYNOPSIS
 
